TODO
====

* Add a CODE_OF_CONDUCT.md

* Add a CONTRIBUTING.md


* Enable `Read the Docs <https://readthedocs.org>`__. (Note: this
  project contains a ``.readthedocs.yml`` file that should be enough
  to get things working.)

* Set up continuous integration: Currently, this project is set up to
  test on Linux and MacOS using Travis, on Windows using Appveyor, and
  to test on PyPy.

* Enable `Codecov <https://codecov.io>`__ for your repo.

